@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.7.2-0
+# Application Name - Health Check V0.7.3-0
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -599,7 +599,7 @@ class Ui_MainWindow(object):
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_5)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V0.7.2-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
+		self.textBrowser.setText (" Health Check V0.7.3-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -648,197 +648,25 @@ class Ui_MainWindow(object):
 
                 self.listApps.clear()
                 self.checkpkgs()
-                #self.read_names()
                 self.listApps.sortItems()		
 
-	def read_names(self):
-            global dpkg_dir
-            global name_lookup
-            pkg = ''
-
-            # Read though the DPKG status file
-            pkg_stat = open(dpkg_dir + '/status', 'r')
-
-            for line in pkg_stat:
-                    line = line.rstrip()
-
-                    # Extract the package name and display name
-                    if line[0:8] == 'Package:':
-                            pkg = line[9:]
-                    elif line[0:19] == 'Maemo-Display-Name:':
-                            # Only store the display name if it's different
-                            full_name = line[20:]
-
-                            if pkg != full_name:
-                                    name_lookup[pkg] = full_name
-
-                    self.listApps.addItem(full_name)
-
-            pkg_stat.close()
-
-            # Lookup the full display name for a package
-        def get_name(self, pkg):
-                global name_lookup
-
-            # Check whether a full display name exists for this package
-                if name_lookup.has_key(pkg):
-                    return name_lookup[pkg]
-                return
-
-            # Return the filesystem ID for the specified file/directory
-        def get_fsid(self, file):
-                return os.stat(file).st_dev
-
-            # Check whether the specified file is on the rootfs or not
-        def is_rootfs(self, file):
-                global rootfs_id
-                global rootfs_pkg
-
-            # Store the rootfs ID if it hasn't yet been set
-                if rootfs_id == '':
-                        rootfs_id = self.get_fsid('/')
-
-            # Check whether the filesystem ID matches that of the rootfs
-                if self.get_fsid(file) == rootfs_id:
-                    return 1
-                return 0
-
-	# Find the on-disk usage of a file
-	def disk_usage(self, file, seen):
-                # Run stat on the file
-                stat = os.stat(file)
-
-                inode = stat.st_ino
-                if seen.has_key(inode):
-                                return
-
-                seen[inode] = 1
-
-                blksize = stat.st_blksize       # Block size for the disk
-                chunknum = stat.st_blocks       # Number of 512b blocks used by file
-                blk_mult = blksize / 512        # How many 512b chunks are in one block
-
-                # Work out how many blocks the file is actually using
-                blk_count = (chunknum + blk_mult - 1) / blk_mult
-
-                # Return the size in kb
-                return blk_count * blksize / 1024
-
-	# Lookup the sizes for a given package
-	def get_size(self, pkg, list = 0):
-                global dpkg_dir
-
-                # Open the packages .list file
-                try:
-                        pkg_info = open(dpkg_dir + '/info/' + pkg + '.list', 'r')
-                        dulist = {}
-                        seen = {}
-
-                    # Read through and store the paths for files on the rootfs
-                        for file in pkg_info:
-                                file = file.rstrip()
-
-                                if not os.path.isfile(file):
-                                    continue
-                                if os.path.islink(file):
-                                    continue
-                                if not self.is_rootfs(file):
-                                    continue
-
-                                # Lookup the disk usage of the file
-                                size = self.disk_usage(file, seen)
-
-                                if size is None:
-                                        continue
-                                if size == 0:
-                                        continue
-                                dulist[file] = size
-                except IOError:
-                        return
-                finally:
-                        pkg_info.close()
-
-                # Check whether there are any files on the rootfs
-                if len(dulist) == 0:
-                        return
-
-                # Return either the total size or the list of individual file sizes
-                if list == 0:
-                        return sum(dulist.values())
-                else:
-                        return dulist
+	
 
 	# Get the total rootfs size for all non-l10n packages
 	def checkpkgs(self):
-	
-                    # Store the display names for later lookup
-                    global read_names
-
-                    # Loop through all files in the DPKG info directory
-                    for file in os.listdir(dpkg_dir + '/info'):
-                            # Skip any that aren't .list files
-                            if file[-5:] != '.list':
-                                    continue
-
-                        # Skip the l10n packages
-                            if file.find('l10n') > -1:
-                                    continue
-
-                            # Extract the package name
-                            pkg = file[0:len(file) - 5]
-
-                            # Lookup the package rootfs size
-                            size = self.get_size(pkg)
-
-                            # Skip further processing if there's no rootfs usage
-                            if size is None:
-                                    continue
-
-                            # Lookup the package's display name
-                            name = self.get_name(pkg)
-
-                            # If there is one, append it in brackets
-                            if not name is None:
-                                    pkg = pkg + ' (' + name + ')'
-                                            
-
-                            # Output the package size and name
-                            #print '%d\t%s' % (size, pkg)
-                            #self.listApps.addItem(str(pkg) + "\t \t \t (" + str(size) + "kb)")
-                            self.listApps.addItem(str(pkg))
-		
-    
-	# List the rootfs files in the given package (and their sizes)
-	def pkglist(self, pkg):
-			# Lookup the array of files and sizes
-			sizes = self.get_size(pkg, 1)
-
-			# Output the info
-			if not sizes is None:
-					for (file, size) in sizes.items():
-							print "%d\t%s" % (size, file)
-
-	# Report the total rootfs usage for the given package
-	def pkgsize(self, pkg):
-			# Lookup the rootfs usage
-			size = self.get_size(pkg)
-
-			# Report the rootfs usage (or 0 if there is none)
-			if size is None:
-					print '0\t%s' % pkg
-			else:
-					print '%d\t%s' % (size, pkg)
-
-	# Use the first parameter as the command to run.
-	#if sys.argv[1] == 'checkpkgs':
-			#checkpkgs()
-	#elif sys.argv[1] == 'pkglist':
-			#pkglist(sys.argv[2])
-	#elif sys.argv[1] == 'pkgsize':
-			#pkgsize(sys.argv[2])
-
-
-		
+                print " ** Getting applications list **"
+		#gl = os.popen('grep Package: /var/lib/dpkg/available').read()
+		fh = open("/var/lib/dpkg/available","r")
+                igot = fh.readlines()
+                print " ** Adding applications to listbox **"
+                for line in igot:
+                        if line.find("Package:") > -1:
+                                about = line.split()
+                                #print about[0],
+                                self.listApps.addItem(about[1])
+                                self.listApps.sortItems()
+                                
+                
 		
 # Funtion - update GPS - Using lib-location
 	def updateGPS(self, MainWindow):
@@ -900,7 +728,7 @@ class Ui_MainWindow(object):
   
 # Funtion - update Firmware version label
 	def updateMaemoV(self):
-		print " ** Getting formware version **"
+		print " ** Getting firmware version **"
 		# This one reads fremantle version number (Firmware)
 		g = os.popen('dpkg -l "mp-fremantle-*"').read()
 		g = g.strip()[-15:]
@@ -1071,6 +899,11 @@ class Ui_MainWindow(object):
 		ga = ga.strip()
 		self.listWidget2.addItem("WIFI Noise \t\t" + ga.strip())
 
+		print " ** Getting MAC Address **"
+		gl = os.popen('cat /sys/class/ieee80211/phy0/macaddress').read()
+		gl = gl.strip()
+		self.listWidget2.addItem("MAC Address \t\t" + gl.strip())
+
 
 		
 	def updateUptime(self):
@@ -1225,6 +1058,11 @@ class Ui_MainWindow(object):
 		gl = gl.strip()
 		self.listWidget.addItem("CPU Frequency \t\t" + gl.strip())
 
+		print " ** Getting CPU Temperature **"
+		gl = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
+		gl = gl.strip()
+		self.listWidget.addItem("CPU Temp (celcius) \t\t" + gl.strip()[1:])
+
 		#print " ** Getting RAM Used **"
 		#gl = os.popen('free | awk \'/M/ {printf ("%.1f MB\n",$3/1024)}\'').read()
 		#gl = gl.strip()
@@ -1234,22 +1072,25 @@ class Ui_MainWindow(object):
 		#gl = os.popen('free | awk \'/M/ {printf ("%.1f MB\n",$4/1024)}\'').read()
 		#gl = gl.strip()
 		#self.listWidget.addItem("Memory - RAM Free \t" + gl.strip())
-		
-		
+
+		print " ** Getting Backlight Info **"
+		gl = os.popen('cat /sys/class/backlight/acx565akm/brightness').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Backlight Actual Level \t" + gl.strip())
+
+		print " ** Getting Backlight Info MAX **"
+		gl = os.popen('cat /sys/class/backlight/acx565akm/max_brightness').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Backlight Max Level \t\t" + gl.strip())
+
+		print " ** Getting Kernel Info **"
+		gl = os.popen('cat /sys/kernel/vmcoreinfo').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Kernel Core Info \t\t" + gl.strip())
+
 
 		
 
-	def updatemydocs(self):
-		print " ** Getting MyDocs space**"
-		# Call the x-terminal command to read the rootfs free space
-		ge = os.popen('df -h /home/user/MyDocs').read()
-		# Remove some of the faffy bits. I've left the total free and percentage used at the moment, is a little confusing
-		gf = str(ge)[-34:]
-		
-		gf = gf[:-24]
-		
-		
-		self.listWidget.addItem("MyDocs \t\t\t" + gf.strip() + " free")
 		
 # Funtion - update tab.... Originally to update tab1, but using it to collate the functions
 # It has the commented out message boxes, will work on this later
@@ -1257,6 +1098,7 @@ class Ui_MainWindow(object):
 		print " ** Running Update ALL**"
 		self.updateTab1()
 		self.updateTab2()
+		self.listpackages()
 	
 	def updateTab1(self):
 		print " ** Running tab1 update**"
@@ -1267,7 +1109,6 @@ class Ui_MainWindow(object):
 		self.updaterootfs()
 		self.updateAccel()
 		self.updateCPU()
-		self.updatemydocs()
 		self.updateMaemoV()
 		self.updateUptime()
 		self.updateBatt()
@@ -1297,7 +1138,7 @@ class Ui_MainWindow(object):
 		
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V0.7.2-0", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V0.7.3-0", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
